@@ -6,7 +6,7 @@ from rest_framework.exceptions import NotAcceptable, PermissionDenied
 
 from .mixins import CredentialMixin
 
-__all__ = ('LimitOffsetPaginationListAPIView',)
+__all__ = ("LimitOffsetPaginationListAPIView",)
 
 
 class StandardResultsPagination(LimitOffsetPagination):
@@ -28,26 +28,28 @@ class LimitOffsetPaginationListAPIView(CredentialMixin, ListAPIView):
     self.date_form
     self.date_to
     """
+
     limit = None
     offset = None
     pagination_class = StandardResultsPagination
 
-    def _ensure_limit_offset_params(self):
-        if self.limit and self.offset:
-            self.pagination_class.limit = limit
-            self.pagination_class.offset = offset
+    def _ensure_limit_param(self):
+        if self.limit:
+            self.pagination_class.default_limit = self.limit
 
     def _generate_date_params(self, delta: int) -> tuple:
-        date_to = datetime.today().strftime('%Y-%m-%d')
-        date_from = (datetime.today() - timedelta(days=delta)).strftime('%Y-%m-%d')
+        date_to = datetime.today().strftime("%Y-%m-%d")
+        date_from = (datetime.today() - timedelta(days=delta)).strftime("%Y-%m-%d")
         return date_from, date_to
 
     def _get_params(self):
         admin = self.get_check_admin(self.request)
         if not admin:
-            raise PermissionDenied({"status": "error", "message": "this method for admin"})
+            raise PermissionDenied(
+                {"status": "error", "message": "this method for admin"}
+            )
 
-        self._ensure_limit_offset_params()
+        # self._ensure_limit_offset_params()
         self.integration_id = self.request.GET.get("integration_id")
         last_week = self.request.GET.get("last_week", "")
         last_3_days = self.request.GET.get("last_3_days", "")
@@ -66,7 +68,7 @@ class LimitOffsetPaginationListAPIView(CredentialMixin, ListAPIView):
             raise NotAcceptable({"status": "error", "message": "miss date params"})
         self.date_from = date_from
         self.date_to = date_to
-        self.platform_id = self.request.GET['platform_id']
+        self.platform_id = self.request.GET["platform_id"]
 
     def get_calculation(self) -> dict:
         return {}
@@ -76,17 +78,28 @@ class LimitOffsetPaginationListAPIView(CredentialMixin, ListAPIView):
 
     def list(self, request, format=None):
         self._get_params()
+        print(self.limit)
+        self._ensure_limit_param()
         queryset = self.get_queryset()
         page = self.paginate_queryset(queryset)
         if page is not None:
-            serializer = self.get_serializer(page, many=True, context={"calculation": self.get_calculation(),
-                                                                       "response_fields": self.get_fields()})
+            serializer = self.get_serializer(
+                page,
+                many=True,
+                context={
+                    "calculation": self.get_calculation(),
+                    "response_fields": self.get_fields(),
+                },
+            )
             return self.get_paginated_response(serializer.data)
 
         serializer = self.get_serializer(
             queryset,
             many=True,
-            context={"calculation": self.get_calculation(), "response_fields": self.get_fields()}
+            context={
+                "calculation": self.get_calculation(),
+                "response_fields": self.get_fields(),
+            },
         )
 
         return Response(serializer.data)
